# MCP Browser Tools

from .fetch import setup_fetch_tools
from .parse import setup_parse_tools
from .interact import setup_interact_tools
from .search import setup_search_tools
from .convert import setup_convert_tools
from .pdf import setup_pdf_tools
from .save import setup_save_tools
from .control import setup_control_tools
